pub struct LocalUserDataKeyState { /* private fields */ }Expand description
Represents the local user data key, wrapped by user key. This key is used to encrypt local user data (e.g., password generator history).